/***************************************************************************************
*
* ID0.asm
*
* Accompaniment for:
* Guide for Porting Code from SHARC DSPs to TigerSHARC Processors (EE-241)
*
* Written by Andrew Caldwell and Maikel Kokaly-Bannourah 
*	
* June 2004 rev 1.0 
*
* This is a TigerSHARC equivalent version of the SHARC Multiprocessor example
* provided with this EE-note (see EE241.zip)
*
***************************************************************************************/

#define N 16
#define MMS_ID1 0x2400000		// ID1 Multiprocessor Memory Space (MMS) offset value		
#define Auto_DMA0 0x180740		// AutoDMA0 register address

/* DM data section in Memory Block 1 */
.section data1;
.align 4;
.var tx_buff_ID0[N]= "tx_ID0.dat";	// ID0 transmit buffer for external port (DMA) data transfers  
										// to ID1 AutoDMA register

/* PM code in Memory Block 0 */
.section program;

start_ID0:
	
	/* Setting Up of Control Registers */

	j14 = j31 + 0x3a79e7;;			// Initial value after reset (0x279e7) modified 
    SYSCON = j14;;					// for 64-bit Bus width configuration
	
    /* DMA set up */
	
	XR3 = 0x00000000;;		
	XR1 = 0x00000000;;		
	XR2 = 0x00000000;;			
	XR3 = 0x00000000;;		

	XR1 = 0x00040004;;				// Count =4, modify = 4 for quad word accesses
	XR3 = 0x00000000;;				// Disable DMA
	DCS0 = XR3:0;;					// Set up DMA Channel 0 - source 
	DCD0 = XR3:0;;					// Set up DMA Channel 0 - destination

	j0 = j31 + _dma_int;;			// Set up DMA0 interrupt vector
	IVDMA0 = j0;;
	
	/* Enable interrupts - DMA0 and GLOBAL int. */

	xR0 = IMASKH;;					// Read value of IMASKH
	xR1 = 0x10000000;;				// Global interrupts
	xR2 = R1 or R0;;				// OR with contents of IMASKH
	IMASKH = xR2;;					// Write back to IMASKH

 	xR3 = IMASKL;;					// Read value of IMASKL
	xR4 = 0x00004000;;				// DMA0 interrupt
	xR5 = R3 or R4;;				// OR with contents of IMASKL
	IMASKL = xR5;;					// Write back to IMASKL
	
	/* Set up and perform DMA transfers */

										// External port transmit - DMA0
	xr0 = tx_buff_ID0;;						// xr0 = source index = int. mem. DSP_0
	xr1 = 0x00100001;;					// count = 0x10, modify = 1 (normal word)
	xr3 = 0x53000000;;					// int mem,prio=norm,2D=no,word=32-bits,int=yes,RQ=enbl,chain=no
	DCS0 = xr3:0;;						// Set up source for transfer

										// External port transmit - DMA0
	xr0 = Auto_DMA0+MMS_ID1;;			// xr0 = dest index = AutoDMA0 register in DSP_ID1
	xr1 = 0x00100000;;					// count=0x10,modify=0(always wirte to same location-AutoDMA0 reg)
	xr3 = 0x93000000;;					// ext mem,prio=norm,2D=no,word=32-bits,int=yes,RQ=enbl,chain=no
	DCD0 = xr3:0;;						// Set up source for transfer

/* Terminate and wait */
wait0:   jump wait0;;				


_dma_int:

	nop;;nop;;nop;;rti(ABS);;	//	DMA0 Interrupt vector


